@@ -28,10 +28,10 @@
  * When defining own plugins, use the GST_BOILERPLATE ease gobject creation.
  */
 
+#include "gst_private.h"
 #include <stdio.h>
 #include <string.h>
 
-#include "gst_private.h"
 #include "gstghostpad.h"
 #include "gstutils.h"
 #include "gstinfo.h"
@@ -482,6 +482,7 @@ overflow:
  * This function can potentially be very slow if denom > G_MAXUINT32.
  *
  * Returns: @val * @num / @denom, trying to avoid overflows.
+ * In the case of an overflow, this function returns G_MAXUINT64.
  */
 guint64
 gst_util_uint64_scale (guint64 val, guint64 num, guint64 denom)
@@ -528,7 +529,8 @@ do_int64:
  *
  * @num and @denom must be positive integers. @denom cannot be 0.
  *
- * Returns: @val * @num / @denom, avoiding overflow and loss of precision
+ * Returns: @val * @num / @denom, avoiding overflow and loss of precision.
+ * In the case of an overflow, this function returns G_MAXUINT64.
  */
 guint64
 gst_util_uint64_scale_int (guint64 val, gint num, gint denom)
@@ -1437,17 +1439,13 @@ gst_element_link_pads (GstElement * src, const gchar * srcpadname,
   if (srcpadname) {
     GST_CAT_DEBUG (GST_CAT_ELEMENT_PADS, "no link possible from %s:%s to %s",
         GST_DEBUG_PAD_NAME (srcpad), GST_ELEMENT_NAME (dest));
-    if (srcpad)
-      gst_object_unref (srcpad);
-    srcpad = NULL;
     if (destpad)
       gst_object_unref (destpad);
     destpad = NULL;
-  } else {
-    if (srcpad)
-      gst_object_unref (srcpad);
-    srcpad = NULL;
   }
+  if (srcpad)
+    gst_object_unref (srcpad);
+  srcpad = NULL;
 
   if (destpad) {
     /* loop through the existing pads in the destination */
@@ -1463,8 +1461,6 @@ gst_element_link_pads (GstElement * src, const gchar * srcpadname,
               GST_DEBUG_PAD_NAME (temp), GST_DEBUG_PAD_NAME (destpad));
           gst_object_unref (temp);
           gst_object_unref (destpad);
-          if (srcpad)
-            gst_object_unref (srcpad);
           return TRUE;
         }
         if (temp) {
@@ -2325,7 +2321,7 @@ gst_buffer_join (GstBuffer * buf1, GstBuffer * buf2)
  * @dest: buffer to stamp
  * @src: buffer to stamp from
  *
- * Copies additional information (the timestamp, duration, and offset start 
+ * Copies additional information (the timestamp, duration, and offset start
  * and end) from one buffer to the other.
  *
  * This function does not copy any buffer flags or caps.
@@ -3003,6 +2999,8 @@ static void
 push_and_ref (GstPad * pad, GstEvent * event)
 {
   gst_pad_push_event (pad, gst_event_ref (event));
+  /* iterator refs pad, we unref when we are done with it */
+  gst_object_unref (pad);
 }
 
 /**
