@@ -2,12 +2,12 @@
 #  include "config.h"
 #endif
 
-#include <gst/gst.h>
-#include <stdlib.h>
 #include <string.h>
 #include <locale.h>
 #include <glib/gprintf.h>
 
+#include "tools.h"
+
 #define PUT_START_TAG(pfx,tag)                                  \
 G_STMT_START{                                                   \
   g_print ("%*.*s<%s>\n", pfx, pfx, "", tag);                   \
@@ -767,6 +767,7 @@ main (int argc, char *argv[])
         "Show plugin details", NULL},
     {"gst-inspect-scheduler", 's', 0, G_OPTION_ARG_STRING,
         "Show scheduler details", NULL},
+    GST_TOOLS_GOPTION_VERSION,
     {NULL}
   };
   GOptionContext *ctx;
@@ -774,7 +775,7 @@ main (int argc, char *argv[])
 
   setlocale (LC_ALL, "");
 
-  ctx = g_option_context_new ("gst-xmlinspect");
+  ctx = g_option_context_new ("[ELEMENT-NAME | PLUGIN-NAME]");
   g_option_context_add_main_entries (ctx, options, GETTEXT_PACKAGE);
   g_option_context_add_group (ctx, gst_init_get_option_group ());
   if (!g_option_context_parse (ctx, &argc, &argv, &err)) {
@@ -783,6 +784,8 @@ main (int argc, char *argv[])
   }
   g_option_context_free (ctx);
 
+  gst_tools_print_version ("gst-xmlinspect");
+
   PUT_STRING (0, "<?xml version=\"1.0\"?>");
 
   /* if no arguments, print out list of elements */
